#include <stdio.h>
#include <string.h>
#include <map>
#include <string>

#define NUM_CCIES	200

using namespace std;

struct Rate
{
	long long from, to;

	Rate operator *( const Rate &r) const
	{
		Rate ret;

		ret.from = from * r.from;
		ret.to = to * r.to;

		return ret;
	}
	
	bool operator != ( const Rate &r)const
	{
		return from * r.to != r.from * to;
	}

	bool operator < ( const Rate &r)const
	{
		return from * r.to < r.from * to;
	}
};

struct Matrix{
Rate e[NUM_CCIES][NUM_CCIES];
};

int NumCcies;
Matrix rates;

Matrix product( const Matrix &r1, const Matrix &r2)
{
	Matrix ret;
	memset(&ret, 0, sizeof(ret));

	for ( int i=0; i<NumCcies; ++i)
		for ( int j=0; j<NumCcies; ++j)
		{
			Rate val=r1.e[i][j];

			for ( int k=0; k<NumCcies; ++k)
			{
				Rate ratex=r1.e[i][k]*r2.e[k][j];

				if ( ratex < val)
					val=ratex;
			}

			ret.e[i][j]=val;
		}

	return ret;
}

Rate unit = {1,1};
Rate zero = {1,0};

bool check(const Matrix &r)
{
	for ( int i=0; i<NumCcies; ++i)
		if (r.e[i][i] < unit)
			return true;

	return false;
}
#if 0
void print()
{
			for ( int i=0; i<NumCcies; ++i)
			{
				for ( int j=0; j<NumCcies; ++j)
					printf("%ld/%ld\t", rates.e[i][j].from, rates.e[i][j].to);

				printf("\n");
			}
			printf("\n");
}
#endif
int main()
{
	int notfirst=0;

	for(;;)
	{
		map<string,int> ccyind;

		NumCcies=0;

		scanf("%d", &NumCcies);

		if (NumCcies==0)
			break;

		for ( int i=0; i<NumCcies; ++i)
		{
			char ccy[4];
			scanf("%s",ccy);
			ccy[3]=0;
			ccyind.insert(make_pair(ccy,i));
		}

		int Nrates;
		scanf("%d", &Nrates);

		for ( int i=0; i<NumCcies; ++i)
			for ( int j=0; j<NumCcies; ++j)
			{
				rates.e[i][j]=zero;
			}

		for ( int i=0; i<NumCcies; ++i)
			rates.e[i][i]=unit;

		for ( int i=0; i<Nrates; ++i)
		{
			char ccy1[4], ccy2[4];
			int val1, val2;
			
			scanf("%s %s %d:%d",ccy1, ccy2, &val1, &val2);
			ccy1[3]=0; ccy2[3]=0;

			int ind1=ccyind.find(ccy1)->second;
			int ind2=ccyind.find(ccy2)->second;

			rates.e[ind1][ind2].from=val1;
			rates.e[ind1][ind2].to=val2;
		}

		//print();

		if (notfirst)
			printf("\n");
		notfirst=1;

		int i;

		for ( i=0; i<9; ++i)
		{
			rates = product( rates, rates);

		//	print();

			if ( check(rates))
			{
				printf("Arbitrage");
				break;
			}
		}

		if ( i==9)
			printf("Ok");

	}
	return 0;
}
